package com.nemrodsoftware;

import java.io.File;
import java.io.IOException;
import java.util.List;

import com.nemrodsoftware.exception.OperationException;
import com.nemrodsoftware.model.Locale;
import com.nemrodsoftware.model.Module;
import com.nemrodsoftware.model.PermissionEnum;
import com.nemrodsoftware.model.Project;
import com.nemrodsoftware.model.User;

public interface INemrodClient
{
    public abstract void create(Project project) throws OperationException; 

    public abstract void createUser(User user)throws OperationException; 
    
    public abstract void allow(String projectName, String login, PermissionEnum permission) throws OperationException;

    public abstract void delete(String projectName) throws OperationException; 
    
    public abstract void setVisibility(String projectName,Boolean isPublic) throws OperationException;
    
    public abstract void setNbMaxUser(String projectName, Long nbMaxUser) throws OperationException;
    
    public abstract void setNbMaxLocale(String projectName, Long nbMaxLocale) throws OperationException; 
    
    public abstract void setNbMaxMessage(String projectName,Long nbMaxMessage) throws OperationException;
    
    public abstract Long getNbMaxMessage(String projectName) throws OperationException; 

    public abstract Long getNbMaxLocale(String projectName) throws OperationException;

    public abstract Long getNbMaxUser(String projectName) throws OperationException; 

    public abstract void addMember(String projectName, String login) throws OperationException; 
    
    /**
     * @param project
     * @return the list of all locales available for this project
     */
    public abstract List<Locale> listLocale(String project);

    /**
     * @param project
     * @return the list of modules for this project
     */
    public abstract List<Module> listModule(String project);

    /**
     * @param project
     * @param moduleName
     * @param modulePath
     * @return the module with the given name or null if not found 
     */
    public abstract Module findModule(String project, String moduleName, String modulePath);

    /**
     * @param project
     * @param localeName
     * @param module
     * @param exportType
     * @param exportEmptyValues
     * @param exportOnlyApprovedValues
     * @param workFolder
     * @return a file descriptor on the downloaded file
     * @throws IOException if an error occured when downloading the file
     * @throws OperationException 
     */
    public abstract File export(String project, String localeName, Module module, String exportType, boolean exportEmptyValues, boolean exportOnlyApprovedValues, String workFolder) throws IOException, OperationException;

    /**
     * @param project
     * @param format
     * @param module
     * @param modulePath
     * @param masterFile
     * @throws OperationException 
     */
    public abstract void sync(String project, String format, Module module, File masterFile) throws OperationException;

}